@@ -49,7 +49,7 @@ class GCharts extends CMSModule
 
   function GetVersion()
   {
-    return '1.2';
+    return '1.3.1';
   }
 
   function GetHelp()
