@@ -279,6 +279,24 @@ if( $this->CheckPermission('Approve GCharts') )
 	  $groupWidth = $params['groupWidth'];
 	}
 
+	$dataOpacity = '';
+	if (isset($params['dataOpacity']))
+	{
+	  $dataOpacity = $params['dataOpacity'];
+	}
+
+	$avoidOverlappingGridLines = '';
+	if (isset($params['avoidOverlappingGridLines']))
+	{
+	  $avoidOverlappingGridLines = $params['avoidOverlappingGridLines'];
+	}
+
+	$timeline = '';
+	if (isset($params['timeline']))
+	{
+	  $timeline = $params['timeline'];
+	}
+
 if( isset($params['submit']) )
   {
     $error = FALSE;
@@ -301,8 +319,8 @@ if( isset($params['submit']) )
     else
       {
 	$chartid = $db->GenID(cms_db_prefix()."module_gcharts_seq");
-	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts (gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, curveType, chartArea, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)';
-	$dbr = $db->Execute($query, array($chartid, $usedcategory, $element, $name, $data, $axisTitlesPosition, $backgroundColor, $curveType, $chartArea, $colors, $enableInteractivity, $focusTarget, $fontSize, $fontName, $hAxes, $hAxis, $height, $interpolatedNulls, $isStacked, $isHtml, $is3D, $legend, $lineWidth, $slices, $pieSliceBorderColor, $pieSliceText, $pieSliceTextStyle, $pointSize, $reverseCategories, $series, $sliceVisibilityThreshold, $pieResidueSliceColor, $pieResidueSliceLabel, $theme, $title, $titlePosition, $titleTextStyle, $tooltip, $vAxes, $vAxis, $width, $status, $aggregationTarget, $groupWidth));
+	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts (gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, curveType, chartArea, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth, dataOpacity, avoidOverlappingGridLines, timeline) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)';
+	$dbr = $db->Execute($query, array($chartid, $usedcategory, $element, $name, $data, $axisTitlesPosition, $backgroundColor, $curveType, $chartArea, $colors, $enableInteractivity, $focusTarget, $fontSize, $fontName, $hAxes, $hAxis, $height, $interpolatedNulls, $isStacked, $isHtml, $is3D, $legend, $lineWidth, $slices, $pieSliceBorderColor, $pieSliceText, $pieSliceTextStyle, $pointSize, $reverseCategories, $series, $sliceVisibilityThreshold, $pieResidueSliceColor, $pieResidueSliceLabel, $theme, $title, $titlePosition, $titleTextStyle, $tooltip, $vAxes, $vAxis, $width, $status, $aggregationTarget, $groupWidth, $dataOpacity, $avoidOverlappingGridLines, $timeline));
     
 	if( !$dbr )
 	  {
@@ -398,6 +416,9 @@ $smarty->assign('startform', $this->CreateFormStart($id, 'addchart', $returnid,'
 	$smarty->assign('inputwidth', $this->CreateInputText($id, 'width', $width, 30, 255));
 	$smarty->assign('inputaggregationTarget', $this->CreateInputText($id, 'aggregationTarget', $aggregationTarget, 30, 255));
 	$smarty->assign('inputgroupWidth', $this->CreateInputText($id, 'groupWidth', $groupWidth, 30, 255));
+	$smarty->assign('inputdataOpacity', $this->CreateInputText($id, 'dataOpacity', $dataOpacity, 30, 255));
+	$smarty->assign('inputavoidOverlappingGridLines', $this->CreateInputText($id, 'avoidOverlappingGridLines', $avoidOverlappingGridLines, 30, 255));
+	$smarty->assign('inputtimeline', $this->CreateInputText($id, 'timeline', $timeline, 30, 255));
 $smarty->assign('actionid',$id);
 if( $this->CheckPermission('Approve GCharts') )
   {
@@ -454,6 +475,9 @@ $smarty->assign('vAxistext', $this->Lang('vAxis'));
 $smarty->assign('widthtext', $this->Lang('width'));
 $smarty->assign('aggregationTargettext', $this->Lang('aggregationTarget'));
 $smarty->assign('groupWidthtext', $this->Lang('groupWidth'));
+$smarty->assign('dataOpacitytext', $this->Lang('dataOpacity'));
+$smarty->assign('avoidOverlappingGridLinestext', $this->Lang('avoidOverlappingGridLines'));
+$smarty->assign('timelinetext', $this->Lang('timeline'));
 
 // tab stuff.
 $smarty->assign('start_tab_headers',$this->StartTabHeaders());
