@@ -7,7 +7,7 @@ $gCms = cmsms();
 $smarty = &$gCms->GetSmarty();
 $db = $gCms->GetDb();
 
-$query = 'SELECT gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, chartArea, curveType, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth from '.cms_db_prefix().
+$query = 'SELECT gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, chartArea, curveType, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth, dataOpacity, avoidOverlappingGridLines, timeline from '.cms_db_prefix().
    'module_gcharts';
 
 if (isset($params['gcharts_id']))
@@ -69,6 +69,9 @@ while ($result !== false && $row=$result->FetchRow())
    $rec->isStacked = $row['isStacked'];
 
    $rec->groupWidth = $row['groupWidth'];
+   $rec->dataOpacity = $row['dataOpacity'];
+   $rec->avoidOverlappingGridLines = $row['avoidOverlappingGridLines'];
+   $rec->timeline = $row['timeline'];
 
    $rec->title = $row['title'];
    array_push($records,$rec);
