@@ -51,7 +51,7 @@ if( isset( $params['pagenumber'] ) )
     $pagenumber = $params['pagenumber'];
   }
 $startelement = ($pagenumber-1) * $pagelimit;
-$sortby = $this->GetPreference('chart_sortby','gcharts_name DESC');
+$sortby = $this->GetPreference('chart_sortby','gcharts_id ASC');
 $sortlist = array();
 $sortlist[$this->Lang('name_asc')] = 'gcharts_name ASC';
 $sortlist[$this->Lang('name_desc')] = 'gcharts_name DESC';
@@ -268,6 +268,11 @@ $smarty->assign('tooltiptext', $this->Lang('tooltip'));
 $smarty->assign('vAxestext', $this->Lang('vAxes'));
 $smarty->assign('vAxistext', $this->Lang('vAxis'));
 $smarty->assign('widthtext', $this->Lang('width'));
+$smarty->assign('aggregationTargettext', $this->Lang('aggregationTarget'));
+$smarty->assign('groupWidthtext', $this->Lang('groupWidth'));
+$smarty->assign('dataOpacitytext', $this->Lang('dataOpacity'));
+$smarty->assign('avoidOverlappingGridLinestext', $this->Lang('avoidOverlappingGridLines'));
+$smarty->assign('timelinetext', $this->Lang('timeline'));
 
 $gCms = cmsms();
 $theme =& $gCms->variables['admintheme'];
