@@ -23,6 +23,7 @@ $lang['select'] = 'Select';
 $lang['reassign_category'] = 'Re-assign category';
 $lang['delete_selected'] = 'Delete selected';
 $lang['nonamegiven'] = 'No name given';
+$lang['nodatagiven'] = 'No data given';
 $lang['areyousure_deletemultiple'] = 'Are you sure you want to delete the selected charts?';
 $lang['chartadded'] = 'Chart added';
 $lang['chartupdated'] = 'Chart updated';
@@ -69,6 +70,9 @@ $lang['vAxis'] = 'vAxis';
 $lang['width'] = 'Width';
 $lang['aggregationTarget'] = 'Aggregation Target';
 $lang['groupWidth'] = 'Group Width';
+$lang['dataOpacity'] = 'Data Opacity';
+$lang['avoidOverlappingGridLines'] = 'Avoid Overlapping Grid Lines';
+$lang['timeline'] = 'Timeline';
 $lang['error_nochartsselected'] = 'No Charts Were Selected';
 
 $lang['areyousure'] = 'Are you sure you want to delete?';
@@ -85,6 +89,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.0 8 July 2013. Initial Release.</li>
 <li>Version 1.1 15 July 2013. Multiple bug fixes.</li>
 <li>Version 1.2 14 November 2013. Added column charts option plus many bug fixes.</li>
+<li>Version 1.3 5 December 2013. Added Histogram and Timeline chart options plus minor bug fixes and code tidying up.</li>
+<li>Version 1.3.1 11 December 2013. Added the ability for GCharts to create chart div element automatically if no containing element ID is specified and bug fixes.</li>
 </ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module allows for the addition of Google Charts to your website.</p>
