@@ -90,6 +90,9 @@ $flds = "
 	 width C(255),
 	 aggregationTarget C(255),
 	 groupWidth C(255),
+	 dataOpacity C(255),
+	 avoidOverlappingGridLines C(255),
+	 timeline C(255),
 	 status C(25)
 ";
 
@@ -135,6 +138,12 @@ $db->Execute($query, array('3', 'Bar Chart', -1));
 $query = 'INSERT INTO '.cms_db_prefix().'module_gcharts_categories (gcharts_category_id, gcharts_category_name, parent_id, create_date, modified_date) VALUES (?,?,?,'.$db->DBTimeStamp(time()).','.$db->DBTimeStamp(time()).')';
 $db->Execute($query, array('4', 'Column Chart', -1));
 
+$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts_categories (gcharts_category_id, gcharts_category_name, parent_id, create_date, modified_date) VALUES (?,?,?,'.$db->DBTimeStamp(time()).','.$db->DBTimeStamp(time()).')';
+$db->Execute($query, array('5', 'Histogram', -1));
+
+$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts_categories (gcharts_category_id, gcharts_category_name, parent_id, create_date, modified_date) VALUES (?,?,?,'.$db->DBTimeStamp(time()).','.$db->DBTimeStamp(time()).')';
+$db->Execute($query, array('6', 'Timeline', -1));
+
 # Setup detail template
 $fn = dirname(__FILE__).DIRECTORY_SEPARATOR.
   'templates'.DIRECTORY_SEPARATOR.'gcharts_list.tpl';
