@@ -56,6 +56,22 @@ switch($current_version) {
 
 	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts_categories (gcharts_category_id, gcharts_category_name, parent_id, create_date, modified_date) VALUES (?,?,?,'.$db->DBTimeStamp(time()).','.$db->DBTimeStamp(time()).')';
 	$db->Execute($query, array('4', 'Column Chart', -1));
+ case "1.3":
+	$fields = '
+		dataOpacity C(255),
+	 	avoidOverlappingGridLines C(255),
+	 	timeline C(255)
+	';
+
+	$sqlarray = $dict->AddColumnSQL(cms_db_prefix() . 'module_gcharts', $fields, $taboptarray);
+	$dict->ExecuteSQLArray($sqlarray);
+
+	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts_categories (gcharts_category_id, gcharts_category_name, parent_id, create_date, modified_date) VALUES (?,?,?,'.$db->DBTimeStamp(time()).','.$db->DBTimeStamp(time()).')';
+	$db->Execute($query, array('5', 'Histogram', -1));
+
+	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts_categories (gcharts_category_id, gcharts_category_name, parent_id, create_date, modified_date) VALUES (?,?,?,'.$db->DBTimeStamp(time()).','.$db->DBTimeStamp(time()).')';
+	$db->Execute($query, array('6', 'Timeline', -1));
+ case "1.3.1":
 
 }
 
